pydist2 package
===============

Submodules
----------

pydist2.custom\_typing module
-----------------------------

.. automodule:: pydist2.custom_typing
   :members:
   :undoc-members:
   :show-inheritance:

pydist2.distance module
-----------------------

.. automodule:: pydist2.distance
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pydist2
   :members:
   :undoc-members:
   :show-inheritance:
